from abc import ABCMeta, abstractmethod
from messagebus import Message


class SendMessageAdapter(object):
    __metaclass__ = ABCMeta

    @abstractmethod
    def send_message(self, component, message):
        # type: (str, Message) -> Message
        raise NotImplementedError()
