from abc import ABCMeta, abstractmethod
from messagebus import Event, Message


class PublishEventAdapter(object):
    __metaclass__ = ABCMeta

    @abstractmethod
    def publish_event(self, event):
        # type: (Event) -> Message
        raise NotImplementedError()
